@@ -7,7 +7,7 @@
 //
 // Developed by Georg Drenkhahn, georg-d@users.sourceforge.net
 //
-// $Id: pendulum.cpp,v 1.4 2005/01/07 11:14:10 mlaurent Exp $
+// $Id: pendulum.cpp 501235 2006-01-22 14:06:24Z mueller $
 //
 /*
  * Copyright (C) 2004 Georg Drenkhahn
@@ -22,12 +22,10 @@
  *
  * You should have received a copy of the GNU General Public License along with
  * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA 02111-1307 USA
+ * Place, Suite 330, Boston, MA 02110-1301 USA
  */
 //============================================================================
 
-#define QT_NO_COMPAT
-
 // std. C++ headers
 #include <cstdlib>
 
@@ -854,7 +852,7 @@ void KPendulumSetup::persChangeEnteredSlot(int t)
 void KPendulumSetup::barColorButtonClickedSlot(void)
 {
    QColor color = QColorDialog::getColor(
-      saver->barColor(), this, QString("bar color dialog"));
+      saver->barColor(), this, "bar color dialog");
    if (color.isValid())
    {
       saver->setBarColor(color);
@@ -864,7 +862,7 @@ void KPendulumSetup::barColorButtonClickedSlot(void)
 void KPendulumSetup::m1ColorButtonClickedSlot(void)
 {
    QColor color = QColorDialog::getColor(
-      saver->m1Color(), this, QString("mass 1 color dialog"));
+      saver->m1Color(), this, "mass 1 color dialog");
    if (color.isValid())
    {
       saver->setM1Color(color);
@@ -874,7 +872,7 @@ void KPendulumSetup::m1ColorButtonClickedSlot(void)
 void KPendulumSetup::m2ColorButtonClickedSlot(void)
 {
    QColor color = QColorDialog::getColor(
-      saver->m2Color(), this, QString("mass 2 color dialog"));
+      saver->m2Color(), this, "mass 2 color dialog");
    if (color.isValid())
    {
       saver->setM2Color(color);
